@@ -47,23 +47,19 @@ sub predraw_cb {
 
 sub InitPlot {
   my $theFac;  
-  $mainplot->SetAttribute(
-    TITLE => "Sample Plot",
-    AXS_XORIGIN=>0,
-    AXS_YORIGIN=>0,
-    #TITLEFONTSIZE => 1.2,
-    TITLEFONTSTYLE => 'BOLD',
-    MARGINTOP => "40",
-    OPENGL=>"YES",
-  );
+  $mainplot->SetAttribute("TITLE", "Sample Plot");
+  $mainplot->TITLEFONTSIZE(12);
+  $mainplot->TITLEFONTSTYLE('BOLD');
+  $mainplot->SetAttribute("MARGINTOP", "40");
 
   $theFac = 100.0/(100*100*100);
-  my (@x, @y);
+  $mainplot->PlotBegin(0);
   for (my $theI=-10; $theI<=10; $theI++) {
-    push @x, (0.001*$theI);
-    push @y, (0.01+$theFac*$theI*$theI*$theI);
+    my $x = (0.001*$theI);
+    my $y = (0.01+$theFac*$theI*$theI*$theI);
+    $mainplot->PlotAdd($x, $y);
   }
-  $mainplot->PlotBegin(2)->PlotAdd2D(\@x, \@y)->PlotEnd;
+  $mainplot->PlotEnd();
   #$mainplot->SetAttribute("DS_COLOR", "100 100 200");
   #$mainplot->SetAttribute("DS_EDIT", "YES");
   $mainplot->SetCallback("DELETE_CB", \&delete_cb);
@@ -261,8 +257,7 @@ sub bt2_cb {
 sub bt3_cb {
   my $self = shift;
   warn "Draw '", $mainfunc->VALUE, "'\n";
-  my @xvalues;  
-  my @yvalues;  
+  my @values;  
   my $y;
   for (my $x=-10; $x<=10; $x+=0.1) {    
     $y = eval $mainfunc->VALUE;
@@ -272,12 +267,14 @@ sub bt3_cb {
       IUP->Message("ERROR", $msg);
       last;
     }
-    push @xvalues, $x;
-    push @yvalues, $y;
+    push @values, $x, $y;
   }
 
   $mainplot->CLEAR(1);
-  $mainplot->PlotSet2D($mainplot->PlotNewDataSet(2), \@xvalues, \@yvalues);  
+  $mainplot->PlotBegin(0);
+  my $index = $mainplot->PlotEnd();
+  $mainplot->PlotAddPoints($index, \@values);  
+  
   $mainplot->SetAttribute("TITLE", 'func: $y='.$mainfunc->VALUE);
   $mainplot->SetAttribute("AXS_XAUTOMIN", "YES");
   $mainplot->SetAttribute("AXS_XAUTOMAX", "YES");
@@ -334,7 +331,6 @@ my $vboxl = IUP::Vbox->new( child=>[$f1, $f2, $lbl1, $tgg3, $tgg4, $lbl2, $tgg5,
 
 ### right panel: plot control
 $mainplot = IUP::PPlot->new();
-#$mainplot = IUP::MglPlot->new();
 $mainfunc = IUP::Text->new( VALUE=>'sin($x)', VISIBLECOLUMNS=>50, VISIBLELINES=>3, MULTILINE=>'YES', EXPAND=>'YES');
 
 ### the main dialog
